REM SICHelp.bas v64.0a r7.5a - Symbolic Instruction Code Kit; help module.

DECLARE SUB ListHelp ()
DECLARE SUB ListHelpFile ()
DECLARE SUB MorePrompt1 (I$, M$, O$)
DECLARE SUB KeyPrompt ()
DECLARE SUB ListHelpFile2 ()

' get standard include declarations
REM $INCLUDE: 'SIC16.INC'

' declare global error routine
ON ERROR GOTO ErrorRoutine

' setup screen
WIDTH 80, 25
COLOR Black
CLS
LOCATE 25, 1, 0
COLOR White, Blue
PRINT SPACE$(80);
LOCATE 25, 1, 0
PRINT "SICK Help Menu "; DATE$; " "; TIME$; " v"; Version; " r"; Release;
COLOR White, Black
LOCATE 24, 1, 1

' run program from command line
CALL ListHelp

' exit to dos
ErrorResume:
COLOR Plain, Black
WHILE INKEY$ <> Nul
WEND
PRINT "Exiting to system.."
END

' standard error trap for all Sic functions.
ErrorRoutine:
IF POS(0) > 1 THEN
   PRINT
END IF
COLOR White, Black
PRINT "Help utility error"; ERR
IF ERR = 53 THEN
   PRINT "File "; Filename; " not found."
END IF
RESUME ErrorResume

REM $DYNAMIC
' prompts for a keystroke
SUB KeyPrompt
   COLOR White, Black
   LOCATE , , 1
   PRINT "Press any key to continue:";
   InputChar$ = Nul
   DO
      InputChar$ = INKEY$
      IF LEN(InputChar$) THEN
         EXIT DO
      END IF
   LOOP
   PRINT
END SUB

' display help menu
SUB ListHelp
   DO
      COLOR White, Black
      PRINT "Help utility SIC v" + Version + " r" + Release + " list:"
      COLOR Yellow, Black
      PRINT "[1]command list"
      PRINT "[2]general documentation"
      PRINT "[3]formatting information"
      PRINT "[4]screen mode tables"
      PRINT "[5]error code values"
      PRINT "[6]syntax documentation"
      PRINT "[7]boolean syntax/charts"
      PRINT "[8]troolean syntax/charts"
      PRINT "[9]disclaimer notice"
      PRINT "[A]shareware information"
      PRINT "[B]version list"
      CALL MorePrompt1("Enter(1-B, Q to quit)?", "123456789abq" + CHR$(13), OutputChar$)
      IF OutputChar$ = CHR$(13) THEN OutputChar$ = "q"
      SELECT CASE OutputChar$
         CASE "1"
            Filename = "menu4.doc"
            CALL ListHelpFile2
         CASE "2"
            Filename = "sic64.doc"
            CALL ListHelpFile
         CASE "3"
            Filename = "sicform.doc"
            CALL ListHelpFile
         CASE "4"
            Filename = "sicscrn.doc"
            CALL ListHelpFile
         CASE "5"
            Filename = "error.doc"
            CALL ListHelpFile
         CASE "6"
            Filename = "syntax.doc"
            CALL ListHelpFile
         CASE "7"
            Filename = "boolean.doc"
            CALL ListHelpFile
         CASE "8"
            Filename = "troolean.doc"
            CALL ListHelpFile
         CASE "9"
            Filename = "disclaim.doc"
            CALL ListHelpFile
         CASE "a"
            Filename = "disclam2.doc"
            CALL ListHelpFile
         CASE "b"
            Filename = "version.lst"
            CALL ListHelpFile
         CASE "q"
            EXIT DO
      END SELECT
   LOOP
END SUB

' displays a help file
SUB ListHelpFile
   CLOSE
   OPEN Filename$ FOR BINARY AS #1
   X# = LOF(1)
   CLOSE
   IF X# = 0# THEN
      PRINT "Helpfile " + CHR$(34) + Filename + CHR$(34) + " not found."
      'PRINT "Set environment path variable to point at SIC64 files."
      CALL MorePrompt1("More(y/n)?", "yn" + CHR$(13), OutputChar$)
      EXIT SUB
   END IF
   CLOSE
   OPEN Filename$ FOR INPUT AS #1
   Continuous = False
   LineCount = False
   DO WHILE NOT EOF(1)
      COLOR Yellow, Black
      LINE INPUT #1, InputLine$
      PRINT InputLine$
      IF Continuous = False THEN
         LineCount = LineCount + 1
         IF LineCount = 23 THEN
            LineCount = False
            CALL MorePrompt1("More(y/n/c)?", "ync" + CHR$(13), OutputChar$)
            SELECT CASE OutputChar$
               CASE "n"
                  EXIT DO
               CASE "c"
                  Continuous = True
            END SELECT
         END IF
      END IF
   LOOP
   CALL KeyPrompt
END SUB

' displays a custom help file
SUB ListHelpFile2
   CLOSE
   OPEN Filename$ FOR BINARY AS #1
   X# = LOF(1)
   CLOSE
   IF X# = 0# THEN
      PRINT "Helpfile " + CHR$(34) + Filename + CHR$(34) + " not found."
      'PRINT "Set environment path variable to point at SIC64 files."
      CALL MorePrompt1("More(y/n)?", "yn" + CHR$(13), OutputChar$)
      EXIT SUB
   END IF
   CLOSE
   FileNumber = 1
   OPEN Filename$ FOR INPUT AS #FileNumber
   Continuous = False
   LineCount = False
   DO WHILE NOT EOF(FileNumber)
      COLOR Yellow, Black
      LINE INPUT #FileNumber, InputLine$
      GOSUB ConvertColor
      IF VarX THEN
         GOTO NextHelpLine
      END IF
      IF LEFT$(LTRIM$(InputLine$), 1) = ";" THEN
         GOTO NextHelpLine
      END IF
      IF LCASE$(InputLine$) = "<more>" THEN
         IF LineCount > 0 THEN
            LineCount = 23
            GOSUB DisplayMore
         END IF
         GOTO NextHelpLine
      END IF
      DO
         V = INSTR(LCASE$(InputLine$), "quote")
         IF V THEN
            InputLine$ = LEFT$(InputLine$, V - 1) + CHR$(34) + MID$(InputLine$, V + 5)
         ELSE
            EXIT DO
         END IF
      LOOP
      PRINT InputLine$
      IF Continuous = False THEN
         LineCount = LineCount + 1
         GOSUB DisplayMore
      END IF
NextHelpLine:
   LOOP
   CALL KeyPrompt
   CLOSE #FileNumber
   FileNumber = False
   EXIT SUB

DisplayMore:
   IF LineCount >= 23 THEN
      LineCount = False
      CALL MorePrompt1("More(y/n/c)?", "ync" + CHR$(13), OutputChar$)
      SELECT CASE LCASE$(OutputChar$)
         CASE "n"
            CALL KeyPrompt
            CLOSE #FileNumber
            FileNumber = False
            EXIT SUB
         CASE "c"
            Continuous = True
      END SELECT
   END IF
   RETURN

ConvertColor:
   VarX = 0
   VarX$ = LCASE$(InputLine$)
   VarX$ = XTRIM$(VarX$, 0)
   SELECT CASE VarX$
      CASE "<color=gray>", "<color=8>"
         COLOR Gray
         VarX = -1
      CASE "<color=blue>", "<color=9>"
         COLOR Blue
         VarX = -1
      CASE "<color=green>", "<color=10>"
         COLOR Green
         VarX = -1
      CASE "<color=cyan>", "<color=11>"
         COLOR Cyan
         VarX = -1
      CASE "<color=red>", "<color=12>"
         COLOR Red
         VarX = -1
      CASE "<color=magenta>", "<color=13>"
         COLOR Magenta
         VarX = -1
      CASE "<color=yellow>", "<color=14>"
         COLOR Yellow
         VarX = -1
      CASE "<color=white>", "<color=15>"
         COLOR White
         VarX = -1
   END SELECT
   RETURN
END SUB

' prompts for multiple input characters
SUB MorePrompt1 (InputString$, InputMask$, OutputString$)
   COLOR White, Black
   PRINT InputString$; " ";
   InputChar$ = Nul
   DO
      LOCATE , , 1
      InputChar$ = INKEY$
      IF LEN(InputChar$) THEN
         InputChar$ = LCASE$(InputChar$)
         IF INSTR(InputMask$, InputChar$) THEN
            IF InputChar$ = CHR$(13) THEN
               PRINT
            ELSE
               PRINT InputChar$
            END IF
            OutputString$ = InputChar$
            EXIT DO
         END IF
      END IF
   LOOP
END SUB

' replaces white spaces with nul,
' var = true; skip spaces in quotes
FUNCTION XTRIM$ (Var$, Var)
   WhiteSpace$ = CHR$(32) + CHR$(9) ' can be changed
   VarX$ = Var$
   Temp = False
   DO
      Temp = Temp + 1
      IF Temp > LEN(VarX$) THEN
         EXIT DO
      END IF
      IF Var THEN
         IF MID$(VarX$, Temp, 1) = CHR$(34) THEN
            DO
               Temp = Temp + 1
               IF Temp > LEN(VarX$) THEN
                  EXIT DO
               END IF
               IF MID$(VarX$, Temp, 1) = CHR$(34) THEN
                  EXIT DO
               END IF
            LOOP
         END IF
      END IF
      FOR Blanks = 1 TO LEN(WhiteSpace$)
         IF MID$(VarX$, Temp, 1) = MID$(WhiteSpace$, Blanks, 1) THEN
            VarX$ = LEFT$(VarX$, Temp - 1) + MID$(VarX$, Temp + 1)
            Temp = Temp - 1
            EXIT FOR
         END IF
      NEXT
   LOOP
   XTRIM$ = VarX$
END FUNCTION

